==> planor_0.1-1.tar.gz: planor/R/planordesign.R <==
#---------------------------------------------------------------------------
# CLASS "planordesign"
#---------------------------------------------------------------------------
# planordesign : an S4 class, typically an output from planor.design.designkey
#         design: a dataframe containing the final design
#         factors: the 'designfactors' object that defines the factors
#         model: the modlist containing the model and estimate specifications
# Methods of "planordesign": none
#---------------------------------------------------------------------------
setClass("planordesign",
         representation(design="data.frame",
                        factors="designfactors",
                        model="list"))
##------------------------------------------------------------------------
## Extraction methods for "planordesign"
##------------------------------------------------------------------------
getDesign.planordesign <- function(object){return(object@design)}
setMethod("getDesign", signature(object="planordesign"),
          definition=getDesign.planordesign)
##--------------------------------------------------------------------------

setMethod("[", 
          signature(x = "planordesign", i = "ANY", j = "ANY", drop = "ANY"),
          definition=function(x,i,j,...,drop){
            if(missing(i)){ i <- seq(nrow(x@design)) }
            if(missing(j)){ j <- names(x@factors) }
            if(is.character(j)){
              jnames <- names(x@factors) %in% j
              j <- seq(jnames)[jnames]
            }
            if(is.logical(j)){
              j <- seq(j)[j]
            }
            x@design <- x@design[ i, j, drop=FALSE ]
            x@factors <- x@factors[ j ]
            keepmodel <- rep(NA, length(x@model))
            for(m in seq_along(x@model)){
              model.names <- unique(
                         all.vars( rev(as.list(x@model[[m]][[1]]))[[1]] ), # model part
                         all.vars( rev(as.list(x@model[[m]][[2]]))[[1]] )) # estimate part
              keepmodel[m] <- all( model.names %in% j )
            }
            x@model <- x@model[keepmodel]
            x
          })
##

==> planor_0.1-10.tar.gz: planor/R/planordesign.R <==
#---------------------------------------------------------------------------
# CLASS "planordesign"
#---------------------------------------------------------------------------
# planordesign : an S4 class, typically an output from planor.design.designkey
#         design: a dataframe containing the final design
#         factors: the 'designfactors' object that defines the factors
#         model: the modlist containing the model and estimate specifications
# designkey, nunits, recursive: data extracted from the  designkey
# from which the object has been built
# Objects of this class are created by calls to planor.design.designkey
#---------------------------------------------------------------------------
setClass("planordesign",
         representation(design="data.frame",
                        factors="designfactors",
                        model="list",
                        designkey="list",
                        nunits="numeric",
                        recursive="logical"))
##------------------------------------------------------------------------
## Extraction methods for "planordesign"
##------------------------------------------------------------------------
getDesign.planordesign <- function(object){return(object@design)}
setMethod("getDesign", signature(object="planordesign"),
          definition=getDesign.planordesign)
##--------------------------------------------------------------------------

setMethod("[",
          signature(x = "planordesign", i = "ANY", j = "ANY", drop = "ANY"),
          definition=function(x,i,j,...,drop){
            if(missing(i)){ i <- seq(nrow(x@design)) }
            if(missing(j)){ j <- names(x@factors) }
            if(is.character(j)){
              jnames <- names(x@factors) %in% j
              j <- seq(jnames)[jnames]
            }
            if(is.logical(j)){
              j <- seq(j)[j]
            }
            x@design <- x@design[ i, j, drop=FALSE ]
            x@factors <- x@factors[ j ]
            keepmodel <- rep(NA, length(x@model))
            for(m in seq_along(x@model)){
              model.names <- unique(
                         all.vars( rev(as.list(x@model[[m]][[1]]))[[1]] ), # model part
                         all.vars( rev(as.list(x@model[[m]][[2]]))[[1]] )) # estimate part
              keepmodel[m] <- all( model.names %in% j )
            }
            x@model <- x@model[keepmodel]
            x
          })
##
##--------------------------------------------------------------------------
#' Method as.data.frame for "planordesign"
# The data.frame is the slot 'design' of the "planordesign" object.
# All the other slots are stored in attributes

as.data.frame.planordesign <- function(x, ...) {
  ret <- x@design
  for (unslot in slotNames(x)) {
    attr(ret, unslot) <- slot(x, unslot)
  }
  return(ret)
} # end as.data.frame.planordesign
